Index: src/heap/heap.h |
diff --git a/src/heap/heap.h b/src/heap/heap.h |
index 8e4952e8a83fb5e2d577a42f50eef38af99c16e9..5067344fc00e8b7c71af3741b006116159f92b3a 100644 |
--- a/src/heap/heap.h |
+++ b/src/heap/heap.h |
@@ -741,9 +741,11 @@ class Heap { |
bool CanMoveObjectStart(HeapObject* object); |
- // Indicates whether live bytes adjustment is triggered from within the GC |
- // code or from mutator code. |
- enum InvocationMode { FROM_GC, FROM_MUTATOR }; |
+ // Indicates whether live bytes adjustment is triggered |
+ // - from within the GC code before sweeping started (SWEEPING_IS_OFF), |
+ // - or from within GC (SWEEPING_STARTED), |
+ // - or mutator code (SWEEPING_STARTED). |
+ enum InvocationMode { SWEEPING_IS_OFF, SWEEPING_STARTED }; |
Hannes Payer (out of office)
2015/03/26 16:27:24
Can we call it SEQUENTIAL_TO_SWEEPER and CONCURREN
|
// Maintain consistency of live bytes during incremental marking. |
void AdjustLiveBytes(Address address, int by, InvocationMode mode); |